pub trait AsMemcachedValue: AsMemcachedValue { }Expand description
A trait for serializing multiple types of values in to appropriate memcached input values for the set and add commands.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".